# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EnterpriseAuthorityTemplateArgs', 'EnterpriseAuthorityTemplate']

@pulumi.input_type
class EnterpriseAuthorityTemplateArgs:
    def __init__(__self__, *,
                 authority_template_name: pulumi.Input[str],
                 tid: pulumi.Input[int],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a EnterpriseAuthorityTemplate resource.
        :param pulumi.Input[str] authority_template_name: Permission Template name.
        :param pulumi.Input[int] tid: Tenant ID.
        :param pulumi.Input[str] description: Permission template description information.
        """
        pulumi.set(__self__, "authority_template_name", authority_template_name)
        pulumi.set(__self__, "tid", tid)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="authorityTemplateName")
    def authority_template_name(self) -> pulumi.Input[str]:
        """
        Permission Template name.
        """
        return pulumi.get(self, "authority_template_name")

    @authority_template_name.setter
    def authority_template_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "authority_template_name", value)

    @property
    @pulumi.getter
    def tid(self) -> pulumi.Input[int]:
        """
        Tenant ID.
        """
        return pulumi.get(self, "tid")

    @tid.setter
    def tid(self, value: pulumi.Input[int]):
        pulumi.set(self, "tid", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Permission template description information.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _EnterpriseAuthorityTemplateState:
    def __init__(__self__, *,
                 authority_template_id: Optional[pulumi.Input[int]] = None,
                 authority_template_name: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 tid: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering EnterpriseAuthorityTemplate resources.
        :param pulumi.Input[int] authority_template_id: Permission template ID.
        :param pulumi.Input[str] authority_template_name: Permission Template name.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] description: Permission template description information.
        :param pulumi.Input[int] tid: Tenant ID.
        """
        if authority_template_id is not None:
            pulumi.set(__self__, "authority_template_id", authority_template_id)
        if authority_template_name is not None:
            pulumi.set(__self__, "authority_template_name", authority_template_name)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if tid is not None:
            pulumi.set(__self__, "tid", tid)

    @property
    @pulumi.getter(name="authorityTemplateId")
    def authority_template_id(self) -> Optional[pulumi.Input[int]]:
        """
        Permission template ID.
        """
        return pulumi.get(self, "authority_template_id")

    @authority_template_id.setter
    def authority_template_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "authority_template_id", value)

    @property
    @pulumi.getter(name="authorityTemplateName")
    def authority_template_name(self) -> Optional[pulumi.Input[str]]:
        """
        Permission Template name.
        """
        return pulumi.get(self, "authority_template_name")

    @authority_template_name.setter
    def authority_template_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "authority_template_name", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Permission template description information.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def tid(self) -> Optional[pulumi.Input[int]]:
        """
        Tenant ID.
        """
        return pulumi.get(self, "tid")

    @tid.setter
    def tid(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tid", value)


class EnterpriseAuthorityTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authority_template_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 tid: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a DMS Enterprise Authority Template resource.

        For information about DMS Enterprise Authority Template and how to use it, see [What is Authority Template](https://www.alibabacloud.com/help/en/dms/developer-reference/api-dms-enterprise-2018-11-01-createauthoritytemplate).

        > **NOTE:** Available since v1.212.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.dms.get_user_tenants(status="ACTIVE")
        default_enterprise_authority_template = alicloud.dms.EnterpriseAuthorityTemplate("default",
            tid=default.ids[0],
            authority_template_name=name,
            description=name)
        ```

        ## Import

        DMS Enterprise Authority Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dms/enterpriseAuthorityTemplate:EnterpriseAuthorityTemplate example <tid>:<authority_template_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] authority_template_name: Permission Template name.
        :param pulumi.Input[str] description: Permission template description information.
        :param pulumi.Input[int] tid: Tenant ID.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnterpriseAuthorityTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a DMS Enterprise Authority Template resource.

        For information about DMS Enterprise Authority Template and how to use it, see [What is Authority Template](https://www.alibabacloud.com/help/en/dms/developer-reference/api-dms-enterprise-2018-11-01-createauthoritytemplate).

        > **NOTE:** Available since v1.212.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.dms.get_user_tenants(status="ACTIVE")
        default_enterprise_authority_template = alicloud.dms.EnterpriseAuthorityTemplate("default",
            tid=default.ids[0],
            authority_template_name=name,
            description=name)
        ```

        ## Import

        DMS Enterprise Authority Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dms/enterpriseAuthorityTemplate:EnterpriseAuthorityTemplate example <tid>:<authority_template_id>
        ```

        :param str resource_name: The name of the resource.
        :param EnterpriseAuthorityTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnterpriseAuthorityTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authority_template_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 tid: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnterpriseAuthorityTemplateArgs.__new__(EnterpriseAuthorityTemplateArgs)

            if authority_template_name is None and not opts.urn:
                raise TypeError("Missing required property 'authority_template_name'")
            __props__.__dict__["authority_template_name"] = authority_template_name
            __props__.__dict__["description"] = description
            if tid is None and not opts.urn:
                raise TypeError("Missing required property 'tid'")
            __props__.__dict__["tid"] = tid
            __props__.__dict__["authority_template_id"] = None
            __props__.__dict__["create_time"] = None
        super(EnterpriseAuthorityTemplate, __self__).__init__(
            'alicloud:dms/enterpriseAuthorityTemplate:EnterpriseAuthorityTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authority_template_id: Optional[pulumi.Input[int]] = None,
            authority_template_name: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            tid: Optional[pulumi.Input[int]] = None) -> 'EnterpriseAuthorityTemplate':
        """
        Get an existing EnterpriseAuthorityTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] authority_template_id: Permission template ID.
        :param pulumi.Input[str] authority_template_name: Permission Template name.
        :param pulumi.Input[str] create_time: The creation time of the resource.
        :param pulumi.Input[str] description: Permission template description information.
        :param pulumi.Input[int] tid: Tenant ID.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnterpriseAuthorityTemplateState.__new__(_EnterpriseAuthorityTemplateState)

        __props__.__dict__["authority_template_id"] = authority_template_id
        __props__.__dict__["authority_template_name"] = authority_template_name
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["tid"] = tid
        return EnterpriseAuthorityTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authorityTemplateId")
    def authority_template_id(self) -> pulumi.Output[int]:
        """
        Permission template ID.
        """
        return pulumi.get(self, "authority_template_id")

    @property
    @pulumi.getter(name="authorityTemplateName")
    def authority_template_name(self) -> pulumi.Output[str]:
        """
        Permission Template name.
        """
        return pulumi.get(self, "authority_template_name")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Permission template description information.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def tid(self) -> pulumi.Output[int]:
        """
        Tenant ID.
        """
        return pulumi.get(self, "tid")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProvisionedProductArgs', 'ProvisionedProduct']

@pulumi.input_type
class ProvisionedProductArgs:
    def __init__(__self__, *,
                 product_id: pulumi.Input[str],
                 product_version_id: pulumi.Input[str],
                 provisioned_product_name: pulumi.Input[str],
                 stack_region_id: pulumi.Input[str],
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]]] = None,
                 portfolio_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a ProvisionedProduct resource.
        :param pulumi.Input[str] product_id: Product ID.
        :param pulumi.Input[str] product_version_id: Product version ID.
        :param pulumi.Input[str] provisioned_product_name: The name of the instance.The length is 1~128 characters.
        :param pulumi.Input[str] stack_region_id: The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        :param pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]] parameters: Template parameters entered by the user.The maximum value of N is 200.See the following `Block Parameters`.
        :param pulumi.Input[str] portfolio_id: Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        :param pulumi.Input[str] provisioned_product_id: The ID of the instance.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "product_id", product_id)
        pulumi.set(__self__, "product_version_id", product_version_id)
        pulumi.set(__self__, "provisioned_product_name", provisioned_product_name)
        pulumi.set(__self__, "stack_region_id", stack_region_id)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if portfolio_id is not None:
            pulumi.set(__self__, "portfolio_id", portfolio_id)
        if provisioned_product_id is not None:
            pulumi.set(__self__, "provisioned_product_id", provisioned_product_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> pulumi.Input[str]:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @product_id.setter
    def product_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "product_id", value)

    @property
    @pulumi.getter(name="productVersionId")
    def product_version_id(self) -> pulumi.Input[str]:
        """
        Product version ID.
        """
        return pulumi.get(self, "product_version_id")

    @product_version_id.setter
    def product_version_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "product_version_id", value)

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> pulumi.Input[str]:
        """
        The name of the instance.The length is 1~128 characters.
        """
        return pulumi.get(self, "provisioned_product_name")

    @provisioned_product_name.setter
    def provisioned_product_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "provisioned_product_name", value)

    @property
    @pulumi.getter(name="stackRegionId")
    def stack_region_id(self) -> pulumi.Input[str]:
        """
        The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        """
        return pulumi.get(self, "stack_region_id")

    @stack_region_id.setter
    def stack_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "stack_region_id", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]]]:
        """
        Template parameters entered by the user.The maximum value of N is 200.See the following `Block Parameters`.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> Optional[pulumi.Input[str]]:
        """
        Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        """
        return pulumi.get(self, "portfolio_id")

    @portfolio_id.setter
    def portfolio_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "portfolio_id", value)

    @property
    @pulumi.getter(name="provisionedProductId")
    def provisioned_product_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "provisioned_product_id")

    @provisioned_product_id.setter
    def provisioned_product_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioned_product_id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ProvisionedProductState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 last_provisioning_task_id: Optional[pulumi.Input[str]] = None,
                 last_successful_provisioning_task_id: Optional[pulumi.Input[str]] = None,
                 last_task_id: Optional[pulumi.Input[str]] = None,
                 outputs: Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductOutputArgs']]]] = None,
                 owner_principal_id: Optional[pulumi.Input[str]] = None,
                 owner_principal_type: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]]] = None,
                 portfolio_id: Optional[pulumi.Input[str]] = None,
                 product_id: Optional[pulumi.Input[str]] = None,
                 product_name: Optional[pulumi.Input[str]] = None,
                 product_version_id: Optional[pulumi.Input[str]] = None,
                 product_version_name: Optional[pulumi.Input[str]] = None,
                 provisioned_product_arn: Optional[pulumi.Input[str]] = None,
                 provisioned_product_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_name: Optional[pulumi.Input[str]] = None,
                 provisioned_product_type: Optional[pulumi.Input[str]] = None,
                 stack_id: Optional[pulumi.Input[str]] = None,
                 stack_region_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 status_message: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering ProvisionedProduct resources.
        :param pulumi.Input[str] create_time: The creation time of the product instance
        :param pulumi.Input[str] last_provisioning_task_id: The ID of the last instance operation task
        :param pulumi.Input[str] last_successful_provisioning_task_id: The ID of the last successful instance operation task
        :param pulumi.Input[str] last_task_id: The ID of the last task
        :param pulumi.Input[Sequence[pulumi.Input['ProvisionedProductOutputArgs']]] outputs: The output value of the template.
        :param pulumi.Input[str] owner_principal_id: The RAM entity ID of the owner
        :param pulumi.Input[str] owner_principal_type: The RAM entity type of the owner
        :param pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]] parameters: Template parameters entered by the user.The maximum value of N is 200.See the following `Block Parameters`.
        :param pulumi.Input[str] portfolio_id: Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        :param pulumi.Input[str] product_id: Product ID.
        :param pulumi.Input[str] product_name: The name of the product
        :param pulumi.Input[str] product_version_id: Product version ID.
        :param pulumi.Input[str] product_version_name: The name of the product version
        :param pulumi.Input[str] provisioned_product_arn: The ARN of the product instance
        :param pulumi.Input[str] provisioned_product_id: The ID of the instance.
        :param pulumi.Input[str] provisioned_product_name: The name of the instance.The length is 1~128 characters.
        :param pulumi.Input[str] provisioned_product_type: Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        :param pulumi.Input[str] stack_id: The ID of the ROS stack
        :param pulumi.Input[str] stack_region_id: The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        :param pulumi.Input[str] status: Instance status
        :param pulumi.Input[str] status_message: The status message of the product instance
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if last_provisioning_task_id is not None:
            pulumi.set(__self__, "last_provisioning_task_id", last_provisioning_task_id)
        if last_successful_provisioning_task_id is not None:
            pulumi.set(__self__, "last_successful_provisioning_task_id", last_successful_provisioning_task_id)
        if last_task_id is not None:
            pulumi.set(__self__, "last_task_id", last_task_id)
        if outputs is not None:
            pulumi.set(__self__, "outputs", outputs)
        if owner_principal_id is not None:
            pulumi.set(__self__, "owner_principal_id", owner_principal_id)
        if owner_principal_type is not None:
            pulumi.set(__self__, "owner_principal_type", owner_principal_type)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if portfolio_id is not None:
            pulumi.set(__self__, "portfolio_id", portfolio_id)
        if product_id is not None:
            pulumi.set(__self__, "product_id", product_id)
        if product_name is not None:
            pulumi.set(__self__, "product_name", product_name)
        if product_version_id is not None:
            pulumi.set(__self__, "product_version_id", product_version_id)
        if product_version_name is not None:
            pulumi.set(__self__, "product_version_name", product_version_name)
        if provisioned_product_arn is not None:
            pulumi.set(__self__, "provisioned_product_arn", provisioned_product_arn)
        if provisioned_product_id is not None:
            pulumi.set(__self__, "provisioned_product_id", provisioned_product_id)
        if provisioned_product_name is not None:
            pulumi.set(__self__, "provisioned_product_name", provisioned_product_name)
        if provisioned_product_type is not None:
            pulumi.set(__self__, "provisioned_product_type", provisioned_product_type)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)
        if stack_region_id is not None:
            pulumi.set(__self__, "stack_region_id", stack_region_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if status_message is not None:
            pulumi.set(__self__, "status_message", status_message)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the product instance
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="lastProvisioningTaskId")
    def last_provisioning_task_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the last instance operation task
        """
        return pulumi.get(self, "last_provisioning_task_id")

    @last_provisioning_task_id.setter
    def last_provisioning_task_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_provisioning_task_id", value)

    @property
    @pulumi.getter(name="lastSuccessfulProvisioningTaskId")
    def last_successful_provisioning_task_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the last successful instance operation task
        """
        return pulumi.get(self, "last_successful_provisioning_task_id")

    @last_successful_provisioning_task_id.setter
    def last_successful_provisioning_task_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_successful_provisioning_task_id", value)

    @property
    @pulumi.getter(name="lastTaskId")
    def last_task_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the last task
        """
        return pulumi.get(self, "last_task_id")

    @last_task_id.setter
    def last_task_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_task_id", value)

    @property
    @pulumi.getter
    def outputs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductOutputArgs']]]]:
        """
        The output value of the template.
        """
        return pulumi.get(self, "outputs")

    @outputs.setter
    def outputs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductOutputArgs']]]]):
        pulumi.set(self, "outputs", value)

    @property
    @pulumi.getter(name="ownerPrincipalId")
    def owner_principal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The RAM entity ID of the owner
        """
        return pulumi.get(self, "owner_principal_id")

    @owner_principal_id.setter
    def owner_principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner_principal_id", value)

    @property
    @pulumi.getter(name="ownerPrincipalType")
    def owner_principal_type(self) -> Optional[pulumi.Input[str]]:
        """
        The RAM entity type of the owner
        """
        return pulumi.get(self, "owner_principal_type")

    @owner_principal_type.setter
    def owner_principal_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner_principal_type", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]]]:
        """
        Template parameters entered by the user.The maximum value of N is 200.See the following `Block Parameters`.
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProvisionedProductParameterArgs']]]]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> Optional[pulumi.Input[str]]:
        """
        Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        """
        return pulumi.get(self, "portfolio_id")

    @portfolio_id.setter
    def portfolio_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "portfolio_id", value)

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> Optional[pulumi.Input[str]]:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @product_id.setter
    def product_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_id", value)

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the product
        """
        return pulumi.get(self, "product_name")

    @product_name.setter
    def product_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_name", value)

    @property
    @pulumi.getter(name="productVersionId")
    def product_version_id(self) -> Optional[pulumi.Input[str]]:
        """
        Product version ID.
        """
        return pulumi.get(self, "product_version_id")

    @product_version_id.setter
    def product_version_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_version_id", value)

    @property
    @pulumi.getter(name="productVersionName")
    def product_version_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the product version
        """
        return pulumi.get(self, "product_version_name")

    @product_version_name.setter
    def product_version_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "product_version_name", value)

    @property
    @pulumi.getter(name="provisionedProductArn")
    def provisioned_product_arn(self) -> Optional[pulumi.Input[str]]:
        """
        The ARN of the product instance
        """
        return pulumi.get(self, "provisioned_product_arn")

    @provisioned_product_arn.setter
    def provisioned_product_arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioned_product_arn", value)

    @property
    @pulumi.getter(name="provisionedProductId")
    def provisioned_product_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "provisioned_product_id")

    @provisioned_product_id.setter
    def provisioned_product_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioned_product_id", value)

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the instance.The length is 1~128 characters.
        """
        return pulumi.get(self, "provisioned_product_name")

    @provisioned_product_name.setter
    def provisioned_product_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioned_product_name", value)

    @property
    @pulumi.getter(name="provisionedProductType")
    def provisioned_product_type(self) -> Optional[pulumi.Input[str]]:
        """
        Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        """
        return pulumi.get(self, "provisioned_product_type")

    @provisioned_product_type.setter
    def provisioned_product_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "provisioned_product_type", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the ROS stack
        """
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter(name="stackRegionId")
    def stack_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        """
        return pulumi.get(self, "stack_region_id")

    @stack_region_id.setter
    def stack_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "stack_region_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Instance status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> Optional[pulumi.Input[str]]:
        """
        The status message of the product instance
        """
        return pulumi.get(self, "status_message")

    @status_message.setter
    def status_message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status_message", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


class ProvisionedProduct(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProvisionedProductParameterArgs', 'ProvisionedProductParameterArgsDict']]]]] = None,
                 portfolio_id: Optional[pulumi.Input[str]] = None,
                 product_id: Optional[pulumi.Input[str]] = None,
                 product_version_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_name: Optional[pulumi.Input[str]] = None,
                 stack_region_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        Provides a Service Catalog Provisioned Product resource.

        For information about Service Catalog Provisioned Product and how to use it, see [What is Provisioned Product](https://www.alibabacloud.com/help/en/service-catalog/developer-reference/api-servicecatalog-2021-09-01-launchproduct).

        > **NOTE:** Available in v1.196.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-testAccServiceCatalogProvisionedProduct"
        default = alicloud.servicecatalog.ProvisionedProduct("default",
            provisioned_product_name=name,
            stack_region_id="cn-hangzhou",
            product_version_id="pv-bp1d7dxy2pcc1g",
            product_id="prod-bp1u3dkc282cwd",
            portfolio_id="port-bp119dvn27jccw",
            tags={
                "v1": "tf-test",
            },
            parameters=[{
                "parameter_key": "role_name",
                "parameter_value": name,
            }])
        ```

        ## Import

        Service Catalog Provisioned Product can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:servicecatalog/provisionedProduct:ProvisionedProduct example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProvisionedProductParameterArgs', 'ProvisionedProductParameterArgsDict']]]] parameters: Template parameters entered by the user.The maximum value of N is 200.See the following `Block Parameters`.
        :param pulumi.Input[str] portfolio_id: Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        :param pulumi.Input[str] product_id: Product ID.
        :param pulumi.Input[str] product_version_id: Product version ID.
        :param pulumi.Input[str] provisioned_product_id: The ID of the instance.
        :param pulumi.Input[str] provisioned_product_name: The name of the instance.The length is 1~128 characters.
        :param pulumi.Input[str] stack_region_id: The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProvisionedProductArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Service Catalog Provisioned Product resource.

        For information about Service Catalog Provisioned Product and how to use it, see [What is Provisioned Product](https://www.alibabacloud.com/help/en/service-catalog/developer-reference/api-servicecatalog-2021-09-01-launchproduct).

        > **NOTE:** Available in v1.196.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-testAccServiceCatalogProvisionedProduct"
        default = alicloud.servicecatalog.ProvisionedProduct("default",
            provisioned_product_name=name,
            stack_region_id="cn-hangzhou",
            product_version_id="pv-bp1d7dxy2pcc1g",
            product_id="prod-bp1u3dkc282cwd",
            portfolio_id="port-bp119dvn27jccw",
            tags={
                "v1": "tf-test",
            },
            parameters=[{
                "parameter_key": "role_name",
                "parameter_value": name,
            }])
        ```

        ## Import

        Service Catalog Provisioned Product can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:servicecatalog/provisionedProduct:ProvisionedProduct example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ProvisionedProductArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProvisionedProductArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProvisionedProductParameterArgs', 'ProvisionedProductParameterArgsDict']]]]] = None,
                 portfolio_id: Optional[pulumi.Input[str]] = None,
                 product_id: Optional[pulumi.Input[str]] = None,
                 product_version_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_id: Optional[pulumi.Input[str]] = None,
                 provisioned_product_name: Optional[pulumi.Input[str]] = None,
                 stack_region_id: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProvisionedProductArgs.__new__(ProvisionedProductArgs)

            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["portfolio_id"] = portfolio_id
            if product_id is None and not opts.urn:
                raise TypeError("Missing required property 'product_id'")
            __props__.__dict__["product_id"] = product_id
            if product_version_id is None and not opts.urn:
                raise TypeError("Missing required property 'product_version_id'")
            __props__.__dict__["product_version_id"] = product_version_id
            __props__.__dict__["provisioned_product_id"] = provisioned_product_id
            if provisioned_product_name is None and not opts.urn:
                raise TypeError("Missing required property 'provisioned_product_name'")
            __props__.__dict__["provisioned_product_name"] = provisioned_product_name
            if stack_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'stack_region_id'")
            __props__.__dict__["stack_region_id"] = stack_region_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["create_time"] = None
            __props__.__dict__["last_provisioning_task_id"] = None
            __props__.__dict__["last_successful_provisioning_task_id"] = None
            __props__.__dict__["last_task_id"] = None
            __props__.__dict__["outputs"] = None
            __props__.__dict__["owner_principal_id"] = None
            __props__.__dict__["owner_principal_type"] = None
            __props__.__dict__["product_name"] = None
            __props__.__dict__["product_version_name"] = None
            __props__.__dict__["provisioned_product_arn"] = None
            __props__.__dict__["provisioned_product_type"] = None
            __props__.__dict__["stack_id"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["status_message"] = None
        super(ProvisionedProduct, __self__).__init__(
            'alicloud:servicecatalog/provisionedProduct:ProvisionedProduct',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            last_provisioning_task_id: Optional[pulumi.Input[str]] = None,
            last_successful_provisioning_task_id: Optional[pulumi.Input[str]] = None,
            last_task_id: Optional[pulumi.Input[str]] = None,
            outputs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProvisionedProductOutputArgs', 'ProvisionedProductOutputArgsDict']]]]] = None,
            owner_principal_id: Optional[pulumi.Input[str]] = None,
            owner_principal_type: Optional[pulumi.Input[str]] = None,
            parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProvisionedProductParameterArgs', 'ProvisionedProductParameterArgsDict']]]]] = None,
            portfolio_id: Optional[pulumi.Input[str]] = None,
            product_id: Optional[pulumi.Input[str]] = None,
            product_name: Optional[pulumi.Input[str]] = None,
            product_version_id: Optional[pulumi.Input[str]] = None,
            product_version_name: Optional[pulumi.Input[str]] = None,
            provisioned_product_arn: Optional[pulumi.Input[str]] = None,
            provisioned_product_id: Optional[pulumi.Input[str]] = None,
            provisioned_product_name: Optional[pulumi.Input[str]] = None,
            provisioned_product_type: Optional[pulumi.Input[str]] = None,
            stack_id: Optional[pulumi.Input[str]] = None,
            stack_region_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            status_message: Optional[pulumi.Input[str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None) -> 'ProvisionedProduct':
        """
        Get an existing ProvisionedProduct resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the product instance
        :param pulumi.Input[str] last_provisioning_task_id: The ID of the last instance operation task
        :param pulumi.Input[str] last_successful_provisioning_task_id: The ID of the last successful instance operation task
        :param pulumi.Input[str] last_task_id: The ID of the last task
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProvisionedProductOutputArgs', 'ProvisionedProductOutputArgsDict']]]] outputs: The output value of the template.
        :param pulumi.Input[str] owner_principal_id: The RAM entity ID of the owner
        :param pulumi.Input[str] owner_principal_type: The RAM entity type of the owner
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProvisionedProductParameterArgs', 'ProvisionedProductParameterArgsDict']]]] parameters: Template parameters entered by the user.The maximum value of N is 200.See the following `Block Parameters`.
        :param pulumi.Input[str] portfolio_id: Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        :param pulumi.Input[str] product_id: Product ID.
        :param pulumi.Input[str] product_name: The name of the product
        :param pulumi.Input[str] product_version_id: Product version ID.
        :param pulumi.Input[str] product_version_name: The name of the product version
        :param pulumi.Input[str] provisioned_product_arn: The ARN of the product instance
        :param pulumi.Input[str] provisioned_product_id: The ID of the instance.
        :param pulumi.Input[str] provisioned_product_name: The name of the instance.The length is 1~128 characters.
        :param pulumi.Input[str] provisioned_product_type: Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        :param pulumi.Input[str] stack_id: The ID of the ROS stack
        :param pulumi.Input[str] stack_region_id: The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        :param pulumi.Input[str] status: Instance status
        :param pulumi.Input[str] status_message: The status message of the product instance
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProvisionedProductState.__new__(_ProvisionedProductState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["last_provisioning_task_id"] = last_provisioning_task_id
        __props__.__dict__["last_successful_provisioning_task_id"] = last_successful_provisioning_task_id
        __props__.__dict__["last_task_id"] = last_task_id
        __props__.__dict__["outputs"] = outputs
        __props__.__dict__["owner_principal_id"] = owner_principal_id
        __props__.__dict__["owner_principal_type"] = owner_principal_type
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["portfolio_id"] = portfolio_id
        __props__.__dict__["product_id"] = product_id
        __props__.__dict__["product_name"] = product_name
        __props__.__dict__["product_version_id"] = product_version_id
        __props__.__dict__["product_version_name"] = product_version_name
        __props__.__dict__["provisioned_product_arn"] = provisioned_product_arn
        __props__.__dict__["provisioned_product_id"] = provisioned_product_id
        __props__.__dict__["provisioned_product_name"] = provisioned_product_name
        __props__.__dict__["provisioned_product_type"] = provisioned_product_type
        __props__.__dict__["stack_id"] = stack_id
        __props__.__dict__["stack_region_id"] = stack_region_id
        __props__.__dict__["status"] = status
        __props__.__dict__["status_message"] = status_message
        __props__.__dict__["tags"] = tags
        return ProvisionedProduct(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the product instance
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="lastProvisioningTaskId")
    def last_provisioning_task_id(self) -> pulumi.Output[str]:
        """
        The ID of the last instance operation task
        """
        return pulumi.get(self, "last_provisioning_task_id")

    @property
    @pulumi.getter(name="lastSuccessfulProvisioningTaskId")
    def last_successful_provisioning_task_id(self) -> pulumi.Output[str]:
        """
        The ID of the last successful instance operation task
        """
        return pulumi.get(self, "last_successful_provisioning_task_id")

    @property
    @pulumi.getter(name="lastTaskId")
    def last_task_id(self) -> pulumi.Output[str]:
        """
        The ID of the last task
        """
        return pulumi.get(self, "last_task_id")

    @property
    @pulumi.getter
    def outputs(self) -> pulumi.Output[Sequence['outputs.ProvisionedProductOutput']]:
        """
        The output value of the template.
        """
        return pulumi.get(self, "outputs")

    @property
    @pulumi.getter(name="ownerPrincipalId")
    def owner_principal_id(self) -> pulumi.Output[str]:
        """
        The RAM entity ID of the owner
        """
        return pulumi.get(self, "owner_principal_id")

    @property
    @pulumi.getter(name="ownerPrincipalType")
    def owner_principal_type(self) -> pulumi.Output[str]:
        """
        The RAM entity type of the owner
        """
        return pulumi.get(self, "owner_principal_type")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[Sequence['outputs.ProvisionedProductParameter']]]:
        """
        Template parameters entered by the user.The maximum value of N is 200.See the following `Block Parameters`.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="portfolioId")
    def portfolio_id(self) -> pulumi.Output[Optional[str]]:
        """
        Product mix ID.> When there is a default Startup option, there is no need to fill in the portfolio. When there is no default Startup option, you must fill in the portfolio.
        """
        return pulumi.get(self, "portfolio_id")

    @property
    @pulumi.getter(name="productId")
    def product_id(self) -> pulumi.Output[str]:
        """
        Product ID.
        """
        return pulumi.get(self, "product_id")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> pulumi.Output[str]:
        """
        The name of the product
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productVersionId")
    def product_version_id(self) -> pulumi.Output[str]:
        """
        Product version ID.
        """
        return pulumi.get(self, "product_version_id")

    @property
    @pulumi.getter(name="productVersionName")
    def product_version_name(self) -> pulumi.Output[str]:
        """
        The name of the product version
        """
        return pulumi.get(self, "product_version_name")

    @property
    @pulumi.getter(name="provisionedProductArn")
    def provisioned_product_arn(self) -> pulumi.Output[str]:
        """
        The ARN of the product instance
        """
        return pulumi.get(self, "provisioned_product_arn")

    @property
    @pulumi.getter(name="provisionedProductId")
    def provisioned_product_id(self) -> pulumi.Output[str]:
        """
        The ID of the instance.
        """
        return pulumi.get(self, "provisioned_product_id")

    @property
    @pulumi.getter(name="provisionedProductName")
    def provisioned_product_name(self) -> pulumi.Output[str]:
        """
        The name of the instance.The length is 1~128 characters.
        """
        return pulumi.get(self, "provisioned_product_name")

    @property
    @pulumi.getter(name="provisionedProductType")
    def provisioned_product_type(self) -> pulumi.Output[str]:
        """
        Instance type.The value is RosStack, which indicates the stack of Alibaba Cloud resource orchestration service (ROS).
        """
        return pulumi.get(self, "provisioned_product_type")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> pulumi.Output[str]:
        """
        The ID of the ROS stack
        """
        return pulumi.get(self, "stack_id")

    @property
    @pulumi.getter(name="stackRegionId")
    def stack_region_id(self) -> pulumi.Output[str]:
        """
        The ID of the region to which the resource stack of the Alibaba Cloud resource orchestration service (ROS) belongs.
        """
        return pulumi.get(self, "stack_region_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        Instance status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="statusMessage")
    def status_message(self) -> pulumi.Output[str]:
        """
        The status message of the product instance
        """
        return pulumi.get(self, "status_message")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .cluster import *
from .engine_namespace import *
from .gateway import *
from .get_clusters import *
from .get_engine_namespaces import *
from .get_gateways import *
from .get_nacos_configs import *
from .get_znodes import *
from .nacos_config import *
from .znode import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .get_end_user_products import *
from .get_launch_options import *
from .get_portfolios import *
from .get_product_as_end_users import *
from .get_product_versions import *
from .get_provisioned_products import *
from .portfolio import *
from .principal_portfolio_association import *
from .product import *
from .product_portfolio_association import *
from .product_version import *
from .provisioned_product import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DefenseTemplateArgs', 'DefenseTemplate']

@pulumi.input_type
class DefenseTemplateArgs:
    def __init__(__self__, *,
                 defense_scene: pulumi.Input[str],
                 defense_template_name: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 status: pulumi.Input[str],
                 template_origin: pulumi.Input[str],
                 template_type: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 resource_manager_resource_group_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DefenseTemplate resource.
        :param pulumi.Input[str] defense_scene: The module to which the protection rule that you want to create belongs. Value:
               - **waf_group**: the basic protection rule module.
               - **antiscan**: the scan protection module.
               - **ip_blacklist**: the IP address blacklist module.
               - **custom_acl**: the custom rule module.
               - **whitelist**: the whitelist module.
               - **region_block**: the region blacklist module.
               - **custom_response**: the custom response module.
               - **cc**: the HTTP flood protection module.
               - **tamperproof**: the website tamper-proofing module.
               - **dlp**: the data leakage prevention module.
        :param pulumi.Input[str] defense_template_name: The name of the protection rule template.
        :param pulumi.Input[str] instance_id: The ID of the Web Application Firewall (WAF) instance. .
        :param pulumi.Input[str] status: The status of the protection rule template. Valid values:
               - **0**: disabled.
               - **1**: enabled.
        :param pulumi.Input[str] template_origin: The origin of the protection rule template that you want to create. Set the value to **custom**. The value specifies that the protection rule template is a custom template. .
        :param pulumi.Input[str] template_type: The type of the protection rule template. Valid values:
               - **user_default:** default template.
               - **user_custom:** custom template.
        :param pulumi.Input[str] description: The description of the protection rule template. .
        :param pulumi.Input[str] resource_manager_resource_group_id: The ID of the Alibaba Cloud resource group. .
        """
        pulumi.set(__self__, "defense_scene", defense_scene)
        pulumi.set(__self__, "defense_template_name", defense_template_name)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "template_origin", template_origin)
        pulumi.set(__self__, "template_type", template_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if resource_manager_resource_group_id is not None:
            pulumi.set(__self__, "resource_manager_resource_group_id", resource_manager_resource_group_id)

    @property
    @pulumi.getter(name="defenseScene")
    def defense_scene(self) -> pulumi.Input[str]:
        """
        The module to which the protection rule that you want to create belongs. Value:
        - **waf_group**: the basic protection rule module.
        - **antiscan**: the scan protection module.
        - **ip_blacklist**: the IP address blacklist module.
        - **custom_acl**: the custom rule module.
        - **whitelist**: the whitelist module.
        - **region_block**: the region blacklist module.
        - **custom_response**: the custom response module.
        - **cc**: the HTTP flood protection module.
        - **tamperproof**: the website tamper-proofing module.
        - **dlp**: the data leakage prevention module.
        """
        return pulumi.get(self, "defense_scene")

    @defense_scene.setter
    def defense_scene(self, value: pulumi.Input[str]):
        pulumi.set(self, "defense_scene", value)

    @property
    @pulumi.getter(name="defenseTemplateName")
    def defense_template_name(self) -> pulumi.Input[str]:
        """
        The name of the protection rule template.
        """
        return pulumi.get(self, "defense_template_name")

    @defense_template_name.setter
    def defense_template_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "defense_template_name", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        The ID of the Web Application Firewall (WAF) instance. .
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[str]:
        """
        The status of the protection rule template. Valid values:
        - **0**: disabled.
        - **1**: enabled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="templateOrigin")
    def template_origin(self) -> pulumi.Input[str]:
        """
        The origin of the protection rule template that you want to create. Set the value to **custom**. The value specifies that the protection rule template is a custom template. .
        """
        return pulumi.get(self, "template_origin")

    @template_origin.setter
    def template_origin(self, value: pulumi.Input[str]):
        pulumi.set(self, "template_origin", value)

    @property
    @pulumi.getter(name="templateType")
    def template_type(self) -> pulumi.Input[str]:
        """
        The type of the protection rule template. Valid values:
        - **user_default:** default template.
        - **user_custom:** custom template.
        """
        return pulumi.get(self, "template_type")

    @template_type.setter
    def template_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "template_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the protection rule template. .
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="resourceManagerResourceGroupId")
    def resource_manager_resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Alibaba Cloud resource group. .
        """
        return pulumi.get(self, "resource_manager_resource_group_id")

    @resource_manager_resource_group_id.setter
    def resource_manager_resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_manager_resource_group_id", value)


@pulumi.input_type
class _DefenseTemplateState:
    def __init__(__self__, *,
                 defense_scene: Optional[pulumi.Input[str]] = None,
                 defense_template_id: Optional[pulumi.Input[int]] = None,
                 defense_template_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 resource_manager_resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 template_origin: Optional[pulumi.Input[str]] = None,
                 template_type: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DefenseTemplate resources.
        :param pulumi.Input[str] defense_scene: The module to which the protection rule that you want to create belongs. Value:
               - **waf_group**: the basic protection rule module.
               - **antiscan**: the scan protection module.
               - **ip_blacklist**: the IP address blacklist module.
               - **custom_acl**: the custom rule module.
               - **whitelist**: the whitelist module.
               - **region_block**: the region blacklist module.
               - **custom_response**: the custom response module.
               - **cc**: the HTTP flood protection module.
               - **tamperproof**: the website tamper-proofing module.
               - **dlp**: the data leakage prevention module.
        :param pulumi.Input[int] defense_template_id: Template ID.
        :param pulumi.Input[str] defense_template_name: The name of the protection rule template.
        :param pulumi.Input[str] description: The description of the protection rule template. .
        :param pulumi.Input[str] instance_id: The ID of the Web Application Firewall (WAF) instance. .
        :param pulumi.Input[str] resource_manager_resource_group_id: The ID of the Alibaba Cloud resource group. .
        :param pulumi.Input[str] status: The status of the protection rule template. Valid values:
               - **0**: disabled.
               - **1**: enabled.
        :param pulumi.Input[str] template_origin: The origin of the protection rule template that you want to create. Set the value to **custom**. The value specifies that the protection rule template is a custom template. .
        :param pulumi.Input[str] template_type: The type of the protection rule template. Valid values:
               - **user_default:** default template.
               - **user_custom:** custom template.
        """
        if defense_scene is not None:
            pulumi.set(__self__, "defense_scene", defense_scene)
        if defense_template_id is not None:
            pulumi.set(__self__, "defense_template_id", defense_template_id)
        if defense_template_name is not None:
            pulumi.set(__self__, "defense_template_name", defense_template_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if resource_manager_resource_group_id is not None:
            pulumi.set(__self__, "resource_manager_resource_group_id", resource_manager_resource_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if template_origin is not None:
            pulumi.set(__self__, "template_origin", template_origin)
        if template_type is not None:
            pulumi.set(__self__, "template_type", template_type)

    @property
    @pulumi.getter(name="defenseScene")
    def defense_scene(self) -> Optional[pulumi.Input[str]]:
        """
        The module to which the protection rule that you want to create belongs. Value:
        - **waf_group**: the basic protection rule module.
        - **antiscan**: the scan protection module.
        - **ip_blacklist**: the IP address blacklist module.
        - **custom_acl**: the custom rule module.
        - **whitelist**: the whitelist module.
        - **region_block**: the region blacklist module.
        - **custom_response**: the custom response module.
        - **cc**: the HTTP flood protection module.
        - **tamperproof**: the website tamper-proofing module.
        - **dlp**: the data leakage prevention module.
        """
        return pulumi.get(self, "defense_scene")

    @defense_scene.setter
    def defense_scene(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defense_scene", value)

    @property
    @pulumi.getter(name="defenseTemplateId")
    def defense_template_id(self) -> Optional[pulumi.Input[int]]:
        """
        Template ID.
        """
        return pulumi.get(self, "defense_template_id")

    @defense_template_id.setter
    def defense_template_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "defense_template_id", value)

    @property
    @pulumi.getter(name="defenseTemplateName")
    def defense_template_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the protection rule template.
        """
        return pulumi.get(self, "defense_template_name")

    @defense_template_name.setter
    def defense_template_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "defense_template_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the protection rule template. .
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Web Application Firewall (WAF) instance. .
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="resourceManagerResourceGroupId")
    def resource_manager_resource_group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Alibaba Cloud resource group. .
        """
        return pulumi.get(self, "resource_manager_resource_group_id")

    @resource_manager_resource_group_id.setter
    def resource_manager_resource_group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_manager_resource_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the protection rule template. Valid values:
        - **0**: disabled.
        - **1**: enabled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="templateOrigin")
    def template_origin(self) -> Optional[pulumi.Input[str]]:
        """
        The origin of the protection rule template that you want to create. Set the value to **custom**. The value specifies that the protection rule template is a custom template. .
        """
        return pulumi.get(self, "template_origin")

    @template_origin.setter
    def template_origin(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_origin", value)

    @property
    @pulumi.getter(name="templateType")
    def template_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the protection rule template. Valid values:
        - **user_default:** default template.
        - **user_custom:** custom template.
        """
        return pulumi.get(self, "template_type")

    @template_type.setter
    def template_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "template_type", value)


class DefenseTemplate(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defense_scene: Optional[pulumi.Input[str]] = None,
                 defense_template_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 resource_manager_resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 template_origin: Optional[pulumi.Input[str]] = None,
                 template_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a WAFV3 Defense Template resource.

        For information about WAFV3 Defense Template and how to use it, see [What is Defense Template](https://www.alibabacloud.com/help/en/web-application-firewall/latest/api-waf-openapi-2021-10-01-createdefensetemplate).

        > **NOTE:** Available since v1.218.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.wafv3.get_instances()
        default_defense_template = alicloud.wafv3.DefenseTemplate("default",
            status="1",
            instance_id=default.ids[0],
            defense_template_name=name,
            template_type="user_custom",
            template_origin="custom",
            defense_scene="antiscan",
            resource_manager_resource_group_id="example",
            description=name)
        ```

        ## Import

        WAFV3 Defense Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:wafv3/defenseTemplate:DefenseTemplate example <instance_id>:<defense_template_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defense_scene: The module to which the protection rule that you want to create belongs. Value:
               - **waf_group**: the basic protection rule module.
               - **antiscan**: the scan protection module.
               - **ip_blacklist**: the IP address blacklist module.
               - **custom_acl**: the custom rule module.
               - **whitelist**: the whitelist module.
               - **region_block**: the region blacklist module.
               - **custom_response**: the custom response module.
               - **cc**: the HTTP flood protection module.
               - **tamperproof**: the website tamper-proofing module.
               - **dlp**: the data leakage prevention module.
        :param pulumi.Input[str] defense_template_name: The name of the protection rule template.
        :param pulumi.Input[str] description: The description of the protection rule template. .
        :param pulumi.Input[str] instance_id: The ID of the Web Application Firewall (WAF) instance. .
        :param pulumi.Input[str] resource_manager_resource_group_id: The ID of the Alibaba Cloud resource group. .
        :param pulumi.Input[str] status: The status of the protection rule template. Valid values:
               - **0**: disabled.
               - **1**: enabled.
        :param pulumi.Input[str] template_origin: The origin of the protection rule template that you want to create. Set the value to **custom**. The value specifies that the protection rule template is a custom template. .
        :param pulumi.Input[str] template_type: The type of the protection rule template. Valid values:
               - **user_default:** default template.
               - **user_custom:** custom template.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DefenseTemplateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a WAFV3 Defense Template resource.

        For information about WAFV3 Defense Template and how to use it, see [What is Defense Template](https://www.alibabacloud.com/help/en/web-application-firewall/latest/api-waf-openapi-2021-10-01-createdefensetemplate).

        > **NOTE:** Available since v1.218.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.wafv3.get_instances()
        default_defense_template = alicloud.wafv3.DefenseTemplate("default",
            status="1",
            instance_id=default.ids[0],
            defense_template_name=name,
            template_type="user_custom",
            template_origin="custom",
            defense_scene="antiscan",
            resource_manager_resource_group_id="example",
            description=name)
        ```

        ## Import

        WAFV3 Defense Template can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:wafv3/defenseTemplate:DefenseTemplate example <instance_id>:<defense_template_id>
        ```

        :param str resource_name: The name of the resource.
        :param DefenseTemplateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DefenseTemplateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 defense_scene: Optional[pulumi.Input[str]] = None,
                 defense_template_name: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 resource_manager_resource_group_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 template_origin: Optional[pulumi.Input[str]] = None,
                 template_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DefenseTemplateArgs.__new__(DefenseTemplateArgs)

            if defense_scene is None and not opts.urn:
                raise TypeError("Missing required property 'defense_scene'")
            __props__.__dict__["defense_scene"] = defense_scene
            if defense_template_name is None and not opts.urn:
                raise TypeError("Missing required property 'defense_template_name'")
            __props__.__dict__["defense_template_name"] = defense_template_name
            __props__.__dict__["description"] = description
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["resource_manager_resource_group_id"] = resource_manager_resource_group_id
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            if template_origin is None and not opts.urn:
                raise TypeError("Missing required property 'template_origin'")
            __props__.__dict__["template_origin"] = template_origin
            if template_type is None and not opts.urn:
                raise TypeError("Missing required property 'template_type'")
            __props__.__dict__["template_type"] = template_type
            __props__.__dict__["defense_template_id"] = None
        super(DefenseTemplate, __self__).__init__(
            'alicloud:wafv3/defenseTemplate:DefenseTemplate',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            defense_scene: Optional[pulumi.Input[str]] = None,
            defense_template_id: Optional[pulumi.Input[int]] = None,
            defense_template_name: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            resource_manager_resource_group_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            template_origin: Optional[pulumi.Input[str]] = None,
            template_type: Optional[pulumi.Input[str]] = None) -> 'DefenseTemplate':
        """
        Get an existing DefenseTemplate resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] defense_scene: The module to which the protection rule that you want to create belongs. Value:
               - **waf_group**: the basic protection rule module.
               - **antiscan**: the scan protection module.
               - **ip_blacklist**: the IP address blacklist module.
               - **custom_acl**: the custom rule module.
               - **whitelist**: the whitelist module.
               - **region_block**: the region blacklist module.
               - **custom_response**: the custom response module.
               - **cc**: the HTTP flood protection module.
               - **tamperproof**: the website tamper-proofing module.
               - **dlp**: the data leakage prevention module.
        :param pulumi.Input[int] defense_template_id: Template ID.
        :param pulumi.Input[str] defense_template_name: The name of the protection rule template.
        :param pulumi.Input[str] description: The description of the protection rule template. .
        :param pulumi.Input[str] instance_id: The ID of the Web Application Firewall (WAF) instance. .
        :param pulumi.Input[str] resource_manager_resource_group_id: The ID of the Alibaba Cloud resource group. .
        :param pulumi.Input[str] status: The status of the protection rule template. Valid values:
               - **0**: disabled.
               - **1**: enabled.
        :param pulumi.Input[str] template_origin: The origin of the protection rule template that you want to create. Set the value to **custom**. The value specifies that the protection rule template is a custom template. .
        :param pulumi.Input[str] template_type: The type of the protection rule template. Valid values:
               - **user_default:** default template.
               - **user_custom:** custom template.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DefenseTemplateState.__new__(_DefenseTemplateState)

        __props__.__dict__["defense_scene"] = defense_scene
        __props__.__dict__["defense_template_id"] = defense_template_id
        __props__.__dict__["defense_template_name"] = defense_template_name
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["resource_manager_resource_group_id"] = resource_manager_resource_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["template_origin"] = template_origin
        __props__.__dict__["template_type"] = template_type
        return DefenseTemplate(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="defenseScene")
    def defense_scene(self) -> pulumi.Output[str]:
        """
        The module to which the protection rule that you want to create belongs. Value:
        - **waf_group**: the basic protection rule module.
        - **antiscan**: the scan protection module.
        - **ip_blacklist**: the IP address blacklist module.
        - **custom_acl**: the custom rule module.
        - **whitelist**: the whitelist module.
        - **region_block**: the region blacklist module.
        - **custom_response**: the custom response module.
        - **cc**: the HTTP flood protection module.
        - **tamperproof**: the website tamper-proofing module.
        - **dlp**: the data leakage prevention module.
        """
        return pulumi.get(self, "defense_scene")

    @property
    @pulumi.getter(name="defenseTemplateId")
    def defense_template_id(self) -> pulumi.Output[int]:
        """
        Template ID.
        """
        return pulumi.get(self, "defense_template_id")

    @property
    @pulumi.getter(name="defenseTemplateName")
    def defense_template_name(self) -> pulumi.Output[str]:
        """
        The name of the protection rule template.
        """
        return pulumi.get(self, "defense_template_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the protection rule template. .
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        The ID of the Web Application Firewall (WAF) instance. .
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="resourceManagerResourceGroupId")
    def resource_manager_resource_group_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the Alibaba Cloud resource group. .
        """
        return pulumi.get(self, "resource_manager_resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the protection rule template. Valid values:
        - **0**: disabled.
        - **1**: enabled.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="templateOrigin")
    def template_origin(self) -> pulumi.Output[str]:
        """
        The origin of the protection rule template that you want to create. Set the value to **custom**. The value specifies that the protection rule template is a custom template. .
        """
        return pulumi.get(self, "template_origin")

    @property
    @pulumi.getter(name="templateType")
    def template_type(self) -> pulumi.Output[str]:
        """
        The type of the protection rule template. Valid values:
        - **user_default:** default template.
        - **user_custom:** custom template.
        """
        return pulumi.get(self, "template_type")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAccountDeletionCheckTaskResult',
    'AwaitableGetAccountDeletionCheckTaskResult',
    'get_account_deletion_check_task',
    'get_account_deletion_check_task_output',
]

@pulumi.output_type
class GetAccountDeletionCheckTaskResult:
    """
    A collection of values returned by getAccountDeletionCheckTask.
    """
    def __init__(__self__, abandon_able_checks=None, account_id=None, allow_delete=None, id=None, not_allow_reasons=None, status=None):
        if abandon_able_checks and not isinstance(abandon_able_checks, list):
            raise TypeError("Expected argument 'abandon_able_checks' to be a list")
        pulumi.set(__self__, "abandon_able_checks", abandon_able_checks)
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if allow_delete and not isinstance(allow_delete, bool):
            raise TypeError("Expected argument 'allow_delete' to be a bool")
        pulumi.set(__self__, "allow_delete", allow_delete)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if not_allow_reasons and not isinstance(not_allow_reasons, list):
            raise TypeError("Expected argument 'not_allow_reasons' to be a list")
        pulumi.set(__self__, "not_allow_reasons", not_allow_reasons)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="abandonAbleChecks")
    def abandon_able_checks(self) -> Sequence['outputs.GetAccountDeletionCheckTaskAbandonAbleCheckResult']:
        """
        The check items that you can choose to ignore for the member deletion. Each element contains the following attributes:
        """
        return pulumi.get(self, "abandon_able_checks")

    @property
    @pulumi.getter(name="accountId")
    def account_id(self) -> str:
        return pulumi.get(self, "account_id")

    @property
    @pulumi.getter(name="allowDelete")
    def allow_delete(self) -> bool:
        """
        Indicates whether the member can be deleted.
        """
        return pulumi.get(self, "allow_delete")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="notAllowReasons")
    def not_allow_reasons(self) -> Sequence['outputs.GetAccountDeletionCheckTaskNotAllowReasonResult']:
        """
        The reasons why the member cannot be deleted. Each element contains the following attributes:
        """
        return pulumi.get(self, "not_allow_reasons")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status of the check.
        """
        return pulumi.get(self, "status")


class AwaitableGetAccountDeletionCheckTaskResult(GetAccountDeletionCheckTaskResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountDeletionCheckTaskResult(
            abandon_able_checks=self.abandon_able_checks,
            account_id=self.account_id,
            allow_delete=self.allow_delete,
            id=self.id,
            not_allow_reasons=self.not_allow_reasons,
            status=self.status)


def get_account_deletion_check_task(account_id: Optional[str] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountDeletionCheckTaskResult:
    """
    Using this data source can open Resource Manager Account Deletion Check Task.

    For information about Resource Manager Account Deletion Check Task and how to use it, see [What is Resource Manager Account Deletion Check Task](https://www.alibabacloud.com/help/en/resource-management/latest/check-account-delete).

    > **NOTE:** Available in v1.187.0+.

    > **NOTE:** The member deletion feature is in invitational preview. You can contact the service manager of Alibaba Cloud to apply for a trial.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    task = alicloud.resourcemanager.get_account_deletion_check_task(account_id="your_account_id")
    pulumi.export("abandonAbleChecksIds", [__item.check_id for __item in task.abandon_able_checks])
    ```


    :param str account_id: The ID of the member that you want to delete.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:resourcemanager/getAccountDeletionCheckTask:getAccountDeletionCheckTask', __args__, opts=opts, typ=GetAccountDeletionCheckTaskResult).value

    return AwaitableGetAccountDeletionCheckTaskResult(
        abandon_able_checks=pulumi.get(__ret__, 'abandon_able_checks'),
        account_id=pulumi.get(__ret__, 'account_id'),
        allow_delete=pulumi.get(__ret__, 'allow_delete'),
        id=pulumi.get(__ret__, 'id'),
        not_allow_reasons=pulumi.get(__ret__, 'not_allow_reasons'),
        status=pulumi.get(__ret__, 'status'))
def get_account_deletion_check_task_output(account_id: Optional[pulumi.Input[str]] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAccountDeletionCheckTaskResult]:
    """
    Using this data source can open Resource Manager Account Deletion Check Task.

    For information about Resource Manager Account Deletion Check Task and how to use it, see [What is Resource Manager Account Deletion Check Task](https://www.alibabacloud.com/help/en/resource-management/latest/check-account-delete).

    > **NOTE:** Available in v1.187.0+.

    > **NOTE:** The member deletion feature is in invitational preview. You can contact the service manager of Alibaba Cloud to apply for a trial.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    task = alicloud.resourcemanager.get_account_deletion_check_task(account_id="your_account_id")
    pulumi.export("abandonAbleChecksIds", [__item.check_id for __item in task.abandon_able_checks])
    ```


    :param str account_id: The ID of the member that you want to delete.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:resourcemanager/getAccountDeletionCheckTask:getAccountDeletionCheckTask', __args__, opts=opts, typ=GetAccountDeletionCheckTaskResult)
    return __ret__.apply(lambda __response__: GetAccountDeletionCheckTaskResult(
        abandon_able_checks=pulumi.get(__response__, 'abandon_able_checks'),
        account_id=pulumi.get(__response__, 'account_id'),
        allow_delete=pulumi.get(__response__, 'allow_delete'),
        id=pulumi.get(__response__, 'id'),
        not_allow_reasons=pulumi.get(__response__, 'not_allow_reasons'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NatIpArgs', 'NatIp']

@pulumi.input_type
class NatIpArgs:
    def __init__(__self__, *,
                 nat_gateway_id: pulumi.Input[str],
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 nat_ip: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr_id: Optional[pulumi.Input[str]] = None,
                 nat_ip_description: Optional[pulumi.Input[str]] = None,
                 nat_ip_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a NatIp resource.
        :param pulumi.Input[str] nat_gateway_id: The ID of the Virtual Private Cloud (VPC) NAT gateway for which you want to create the NAT IP address.
        :param pulumi.Input[bool] dry_run: Specifies whether to check the validity of the request without actually making the request.
        :param pulumi.Input[str] nat_ip: The NAT IP address that you want to create. If you do not specify an IP address, the system selects a random IP address from the specified CIDR block.
        :param pulumi.Input[str] nat_ip_cidr: NAT IP ADDRESS of the address segment.
        :param pulumi.Input[str] nat_ip_cidr_id: The ID of the CIDR block to which the NAT IP address belongs.
        :param pulumi.Input[str] nat_ip_description: NAT IP ADDRESS description of information. Length is from `2` to `256` characters, must start with a letter or the Chinese at the beginning, but not at the` http://` Or `https://` at the beginning.
        :param pulumi.Input[str] nat_ip_name: NAT IP ADDRESS the name of the root directory. Length is from `2` to `128` characters, must start with a letter or the Chinese at the beginning can contain numbers, half a period (.), underscore (_) and dash (-). But do not start with `http://` or `https://` at the beginning.
        """
        pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if nat_ip is not None:
            pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_cidr is not None:
            pulumi.set(__self__, "nat_ip_cidr", nat_ip_cidr)
        if nat_ip_cidr_id is not None:
            pulumi.set(__self__, "nat_ip_cidr_id", nat_ip_cidr_id)
        if nat_ip_description is not None:
            pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_name is not None:
            pulumi.set(__self__, "nat_ip_name", nat_ip_name)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Input[str]:
        """
        The ID of the Virtual Private Cloud (VPC) NAT gateway for which you want to create the NAT IP address.
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to check the validity of the request without actually making the request.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The NAT IP address that you want to create. If you do not specify an IP address, the system selects a random IP address from the specified CIDR block.
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="natIpCidr")
    def nat_ip_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        NAT IP ADDRESS of the address segment.
        """
        return pulumi.get(self, "nat_ip_cidr")

    @nat_ip_cidr.setter
    def nat_ip_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_cidr", value)

    @property
    @pulumi.getter(name="natIpCidrId")
    def nat_ip_cidr_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the CIDR block to which the NAT IP address belongs.
        """
        return pulumi.get(self, "nat_ip_cidr_id")

    @nat_ip_cidr_id.setter
    def nat_ip_cidr_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_cidr_id", value)

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> Optional[pulumi.Input[str]]:
        """
        NAT IP ADDRESS description of information. Length is from `2` to `256` characters, must start with a letter or the Chinese at the beginning, but not at the` http://` Or `https://` at the beginning.
        """
        return pulumi.get(self, "nat_ip_description")

    @nat_ip_description.setter
    def nat_ip_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_description", value)

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> Optional[pulumi.Input[str]]:
        """
        NAT IP ADDRESS the name of the root directory. Length is from `2` to `128` characters, must start with a letter or the Chinese at the beginning can contain numbers, half a period (.), underscore (_) and dash (-). But do not start with `http://` or `https://` at the beginning.
        """
        return pulumi.get(self, "nat_ip_name")

    @nat_ip_name.setter
    def nat_ip_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_name", value)


@pulumi.input_type
class _NatIpState:
    def __init__(__self__, *,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 nat_gateway_id: Optional[pulumi.Input[str]] = None,
                 nat_ip: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr_id: Optional[pulumi.Input[str]] = None,
                 nat_ip_description: Optional[pulumi.Input[str]] = None,
                 nat_ip_id: Optional[pulumi.Input[str]] = None,
                 nat_ip_name: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering NatIp resources.
        :param pulumi.Input[bool] dry_run: Specifies whether to check the validity of the request without actually making the request.
        :param pulumi.Input[str] nat_gateway_id: The ID of the Virtual Private Cloud (VPC) NAT gateway for which you want to create the NAT IP address.
        :param pulumi.Input[str] nat_ip: The NAT IP address that you want to create. If you do not specify an IP address, the system selects a random IP address from the specified CIDR block.
        :param pulumi.Input[str] nat_ip_cidr: NAT IP ADDRESS of the address segment.
        :param pulumi.Input[str] nat_ip_cidr_id: The ID of the CIDR block to which the NAT IP address belongs.
        :param pulumi.Input[str] nat_ip_description: NAT IP ADDRESS description of information. Length is from `2` to `256` characters, must start with a letter or the Chinese at the beginning, but not at the` http://` Or `https://` at the beginning.
        :param pulumi.Input[str] nat_ip_id: Ihe ID of the Nat Ip.
        :param pulumi.Input[str] nat_ip_name: NAT IP ADDRESS the name of the root directory. Length is from `2` to `128` characters, must start with a letter or the Chinese at the beginning can contain numbers, half a period (.), underscore (_) and dash (-). But do not start with `http://` or `https://` at the beginning.
        :param pulumi.Input[str] status: The status of the NAT IP address. Valid values: `Available`, `Deleting`, `Creating` and `Deleted`.
        """
        if dry_run is not None:
            pulumi.set(__self__, "dry_run", dry_run)
        if nat_gateway_id is not None:
            pulumi.set(__self__, "nat_gateway_id", nat_gateway_id)
        if nat_ip is not None:
            pulumi.set(__self__, "nat_ip", nat_ip)
        if nat_ip_cidr is not None:
            pulumi.set(__self__, "nat_ip_cidr", nat_ip_cidr)
        if nat_ip_cidr_id is not None:
            pulumi.set(__self__, "nat_ip_cidr_id", nat_ip_cidr_id)
        if nat_ip_description is not None:
            pulumi.set(__self__, "nat_ip_description", nat_ip_description)
        if nat_ip_id is not None:
            pulumi.set(__self__, "nat_ip_id", nat_ip_id)
        if nat_ip_name is not None:
            pulumi.set(__self__, "nat_ip_name", nat_ip_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether to check the validity of the request without actually making the request.
        """
        return pulumi.get(self, "dry_run")

    @dry_run.setter
    def dry_run(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dry_run", value)

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Virtual Private Cloud (VPC) NAT gateway for which you want to create the NAT IP address.
        """
        return pulumi.get(self, "nat_gateway_id")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_gateway_id", value)

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The NAT IP address that you want to create. If you do not specify an IP address, the system selects a random IP address from the specified CIDR block.
        """
        return pulumi.get(self, "nat_ip")

    @nat_ip.setter
    def nat_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip", value)

    @property
    @pulumi.getter(name="natIpCidr")
    def nat_ip_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        NAT IP ADDRESS of the address segment.
        """
        return pulumi.get(self, "nat_ip_cidr")

    @nat_ip_cidr.setter
    def nat_ip_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_cidr", value)

    @property
    @pulumi.getter(name="natIpCidrId")
    def nat_ip_cidr_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the CIDR block to which the NAT IP address belongs.
        """
        return pulumi.get(self, "nat_ip_cidr_id")

    @nat_ip_cidr_id.setter
    def nat_ip_cidr_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_cidr_id", value)

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> Optional[pulumi.Input[str]]:
        """
        NAT IP ADDRESS description of information. Length is from `2` to `256` characters, must start with a letter or the Chinese at the beginning, but not at the` http://` Or `https://` at the beginning.
        """
        return pulumi.get(self, "nat_ip_description")

    @nat_ip_description.setter
    def nat_ip_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_description", value)

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> Optional[pulumi.Input[str]]:
        """
        Ihe ID of the Nat Ip.
        """
        return pulumi.get(self, "nat_ip_id")

    @nat_ip_id.setter
    def nat_ip_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_id", value)

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> Optional[pulumi.Input[str]]:
        """
        NAT IP ADDRESS the name of the root directory. Length is from `2` to `128` characters, must start with a letter or the Chinese at the beginning can contain numbers, half a period (.), underscore (_) and dash (-). But do not start with `http://` or `https://` at the beginning.
        """
        return pulumi.get(self, "nat_ip_name")

    @nat_ip_name.setter
    def nat_ip_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "nat_ip_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the NAT IP address. Valid values: `Available`, `Deleting`, `Creating` and `Deleted`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class NatIp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 nat_gateway_id: Optional[pulumi.Input[str]] = None,
                 nat_ip: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr_id: Optional[pulumi.Input[str]] = None,
                 nat_ip_description: Optional[pulumi.Input[str]] = None,
                 nat_ip_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a VPC Nat Ip resource.

        For information about VPC Nat Ip and how to use it, see [What is Nat Ip](https://www.alibabacloud.com/help/doc-detail/281976.htm).

        > **NOTE:** Available in v1.136.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.get_zones(available_resource_creation="VSwitch")
        example_network = alicloud.vpc.Network("example",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        example_switch = alicloud.vpc.Switch("example",
            vpc_id=example_network.id,
            cidr_block="172.16.0.0/21",
            zone_id=example.zones[0].id,
            vswitch_name="terraform-example")
        example_nat_gateway = alicloud.vpc.NatGateway("example",
            vpc_id=example_network.id,
            internet_charge_type="PayByLcu",
            nat_gateway_name="terraform-example",
            description="terraform-example",
            nat_type="Enhanced",
            vswitch_id=example_switch.id,
            network_type="intranet")
        example_nat_ip_cidr = alicloud.vpc.NatIpCidr("example",
            nat_ip_cidr="192.168.0.0/16",
            nat_gateway_id=example_nat_gateway.id,
            nat_ip_cidr_description="terraform-example",
            nat_ip_cidr_name="terraform-example")
        example_nat_ip = alicloud.vpc.NatIp("example",
            nat_ip="192.168.0.37",
            nat_gateway_id=example_nat_gateway.id,
            nat_ip_description="example_value",
            nat_ip_name="example_value",
            nat_ip_cidr=example_nat_ip_cidr.nat_ip_cidr)
        ```

        ## Import

        VPC Nat Ip can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/natIp:NatIp example <nat_gateway_id>:<nat_ip_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] dry_run: Specifies whether to check the validity of the request without actually making the request.
        :param pulumi.Input[str] nat_gateway_id: The ID of the Virtual Private Cloud (VPC) NAT gateway for which you want to create the NAT IP address.
        :param pulumi.Input[str] nat_ip: The NAT IP address that you want to create. If you do not specify an IP address, the system selects a random IP address from the specified CIDR block.
        :param pulumi.Input[str] nat_ip_cidr: NAT IP ADDRESS of the address segment.
        :param pulumi.Input[str] nat_ip_cidr_id: The ID of the CIDR block to which the NAT IP address belongs.
        :param pulumi.Input[str] nat_ip_description: NAT IP ADDRESS description of information. Length is from `2` to `256` characters, must start with a letter or the Chinese at the beginning, but not at the` http://` Or `https://` at the beginning.
        :param pulumi.Input[str] nat_ip_name: NAT IP ADDRESS the name of the root directory. Length is from `2` to `128` characters, must start with a letter or the Chinese at the beginning can contain numbers, half a period (.), underscore (_) and dash (-). But do not start with `http://` or `https://` at the beginning.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NatIpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a VPC Nat Ip resource.

        For information about VPC Nat Ip and how to use it, see [What is Nat Ip](https://www.alibabacloud.com/help/doc-detail/281976.htm).

        > **NOTE:** Available in v1.136.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.get_zones(available_resource_creation="VSwitch")
        example_network = alicloud.vpc.Network("example",
            vpc_name="terraform-example",
            cidr_block="172.16.0.0/12")
        example_switch = alicloud.vpc.Switch("example",
            vpc_id=example_network.id,
            cidr_block="172.16.0.0/21",
            zone_id=example.zones[0].id,
            vswitch_name="terraform-example")
        example_nat_gateway = alicloud.vpc.NatGateway("example",
            vpc_id=example_network.id,
            internet_charge_type="PayByLcu",
            nat_gateway_name="terraform-example",
            description="terraform-example",
            nat_type="Enhanced",
            vswitch_id=example_switch.id,
            network_type="intranet")
        example_nat_ip_cidr = alicloud.vpc.NatIpCidr("example",
            nat_ip_cidr="192.168.0.0/16",
            nat_gateway_id=example_nat_gateway.id,
            nat_ip_cidr_description="terraform-example",
            nat_ip_cidr_name="terraform-example")
        example_nat_ip = alicloud.vpc.NatIp("example",
            nat_ip="192.168.0.37",
            nat_gateway_id=example_nat_gateway.id,
            nat_ip_description="example_value",
            nat_ip_name="example_value",
            nat_ip_cidr=example_nat_ip_cidr.nat_ip_cidr)
        ```

        ## Import

        VPC Nat Ip can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:vpc/natIp:NatIp example <nat_gateway_id>:<nat_ip_id>
        ```

        :param str resource_name: The name of the resource.
        :param NatIpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NatIpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dry_run: Optional[pulumi.Input[bool]] = None,
                 nat_gateway_id: Optional[pulumi.Input[str]] = None,
                 nat_ip: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr: Optional[pulumi.Input[str]] = None,
                 nat_ip_cidr_id: Optional[pulumi.Input[str]] = None,
                 nat_ip_description: Optional[pulumi.Input[str]] = None,
                 nat_ip_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NatIpArgs.__new__(NatIpArgs)

            __props__.__dict__["dry_run"] = dry_run
            if nat_gateway_id is None and not opts.urn:
                raise TypeError("Missing required property 'nat_gateway_id'")
            __props__.__dict__["nat_gateway_id"] = nat_gateway_id
            __props__.__dict__["nat_ip"] = nat_ip
            __props__.__dict__["nat_ip_cidr"] = nat_ip_cidr
            __props__.__dict__["nat_ip_cidr_id"] = nat_ip_cidr_id
            __props__.__dict__["nat_ip_description"] = nat_ip_description
            __props__.__dict__["nat_ip_name"] = nat_ip_name
            __props__.__dict__["nat_ip_id"] = None
            __props__.__dict__["status"] = None
        super(NatIp, __self__).__init__(
            'alicloud:vpc/natIp:NatIp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dry_run: Optional[pulumi.Input[bool]] = None,
            nat_gateway_id: Optional[pulumi.Input[str]] = None,
            nat_ip: Optional[pulumi.Input[str]] = None,
            nat_ip_cidr: Optional[pulumi.Input[str]] = None,
            nat_ip_cidr_id: Optional[pulumi.Input[str]] = None,
            nat_ip_description: Optional[pulumi.Input[str]] = None,
            nat_ip_id: Optional[pulumi.Input[str]] = None,
            nat_ip_name: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'NatIp':
        """
        Get an existing NatIp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] dry_run: Specifies whether to check the validity of the request without actually making the request.
        :param pulumi.Input[str] nat_gateway_id: The ID of the Virtual Private Cloud (VPC) NAT gateway for which you want to create the NAT IP address.
        :param pulumi.Input[str] nat_ip: The NAT IP address that you want to create. If you do not specify an IP address, the system selects a random IP address from the specified CIDR block.
        :param pulumi.Input[str] nat_ip_cidr: NAT IP ADDRESS of the address segment.
        :param pulumi.Input[str] nat_ip_cidr_id: The ID of the CIDR block to which the NAT IP address belongs.
        :param pulumi.Input[str] nat_ip_description: NAT IP ADDRESS description of information. Length is from `2` to `256` characters, must start with a letter or the Chinese at the beginning, but not at the` http://` Or `https://` at the beginning.
        :param pulumi.Input[str] nat_ip_id: Ihe ID of the Nat Ip.
        :param pulumi.Input[str] nat_ip_name: NAT IP ADDRESS the name of the root directory. Length is from `2` to `128` characters, must start with a letter or the Chinese at the beginning can contain numbers, half a period (.), underscore (_) and dash (-). But do not start with `http://` or `https://` at the beginning.
        :param pulumi.Input[str] status: The status of the NAT IP address. Valid values: `Available`, `Deleting`, `Creating` and `Deleted`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NatIpState.__new__(_NatIpState)

        __props__.__dict__["dry_run"] = dry_run
        __props__.__dict__["nat_gateway_id"] = nat_gateway_id
        __props__.__dict__["nat_ip"] = nat_ip
        __props__.__dict__["nat_ip_cidr"] = nat_ip_cidr
        __props__.__dict__["nat_ip_cidr_id"] = nat_ip_cidr_id
        __props__.__dict__["nat_ip_description"] = nat_ip_description
        __props__.__dict__["nat_ip_id"] = nat_ip_id
        __props__.__dict__["nat_ip_name"] = nat_ip_name
        __props__.__dict__["status"] = status
        return NatIp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dryRun")
    def dry_run(self) -> pulumi.Output[bool]:
        """
        Specifies whether to check the validity of the request without actually making the request.
        """
        return pulumi.get(self, "dry_run")

    @property
    @pulumi.getter(name="natGatewayId")
    def nat_gateway_id(self) -> pulumi.Output[str]:
        """
        The ID of the Virtual Private Cloud (VPC) NAT gateway for which you want to create the NAT IP address.
        """
        return pulumi.get(self, "nat_gateway_id")

    @property
    @pulumi.getter(name="natIp")
    def nat_ip(self) -> pulumi.Output[str]:
        """
        The NAT IP address that you want to create. If you do not specify an IP address, the system selects a random IP address from the specified CIDR block.
        """
        return pulumi.get(self, "nat_ip")

    @property
    @pulumi.getter(name="natIpCidr")
    def nat_ip_cidr(self) -> pulumi.Output[Optional[str]]:
        """
        NAT IP ADDRESS of the address segment.
        """
        return pulumi.get(self, "nat_ip_cidr")

    @property
    @pulumi.getter(name="natIpCidrId")
    def nat_ip_cidr_id(self) -> pulumi.Output[Optional[str]]:
        """
        The ID of the CIDR block to which the NAT IP address belongs.
        """
        return pulumi.get(self, "nat_ip_cidr_id")

    @property
    @pulumi.getter(name="natIpDescription")
    def nat_ip_description(self) -> pulumi.Output[Optional[str]]:
        """
        NAT IP ADDRESS description of information. Length is from `2` to `256` characters, must start with a letter or the Chinese at the beginning, but not at the` http://` Or `https://` at the beginning.
        """
        return pulumi.get(self, "nat_ip_description")

    @property
    @pulumi.getter(name="natIpId")
    def nat_ip_id(self) -> pulumi.Output[str]:
        """
        Ihe ID of the Nat Ip.
        """
        return pulumi.get(self, "nat_ip_id")

    @property
    @pulumi.getter(name="natIpName")
    def nat_ip_name(self) -> pulumi.Output[Optional[str]]:
        """
        NAT IP ADDRESS the name of the root directory. Length is from `2` to `128` characters, must start with a letter or the Chinese at the beginning can contain numbers, half a period (.), underscore (_) and dash (-). But do not start with `http://` or `https://` at the beginning.
        """
        return pulumi.get(self, "nat_ip_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the NAT IP address. Valid values: `Available`, `Deleting`, `Creating` and `Deleted`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['K8sSlbAttachmentArgs', 'K8sSlbAttachment']

@pulumi.input_type
class K8sSlbAttachmentArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[str],
                 slb_configs: Optional[pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]]] = None):
        """
        The set of arguments for constructing a K8sSlbAttachment resource.
        :param pulumi.Input[str] app_id: The ID of the EDAS k8s application to which you want to bind SLB instances.
        :param pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]] slb_configs: The configurations of SLB attachment, which is supported for multiple configurations. See `slb_configs` below.
        """
        pulumi.set(__self__, "app_id", app_id)
        if slb_configs is not None:
            pulumi.set(__self__, "slb_configs", slb_configs)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[str]:
        """
        The ID of the EDAS k8s application to which you want to bind SLB instances.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="slbConfigs")
    def slb_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]]]:
        """
        The configurations of SLB attachment, which is supported for multiple configurations. See `slb_configs` below.
        """
        return pulumi.get(self, "slb_configs")

    @slb_configs.setter
    def slb_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]]]):
        pulumi.set(self, "slb_configs", value)


@pulumi.input_type
class _K8sSlbAttachmentState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[str]] = None,
                 slb_configs: Optional[pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]]] = None):
        """
        Input properties used for looking up and filtering K8sSlbAttachment resources.
        :param pulumi.Input[str] app_id: The ID of the EDAS k8s application to which you want to bind SLB instances.
        :param pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]] slb_configs: The configurations of SLB attachment, which is supported for multiple configurations. See `slb_configs` below.
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if slb_configs is not None:
            pulumi.set(__self__, "slb_configs", slb_configs)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the EDAS k8s application to which you want to bind SLB instances.
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_id", value)

    @property
    @pulumi.getter(name="slbConfigs")
    def slb_configs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]]]:
        """
        The configurations of SLB attachment, which is supported for multiple configurations. See `slb_configs` below.
        """
        return pulumi.get(self, "slb_configs")

    @slb_configs.setter
    def slb_configs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['K8sSlbAttachmentSlbConfigArgs']]]]):
        pulumi.set(self, "slb_configs", value)


class K8sSlbAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 slb_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['K8sSlbAttachmentSlbConfigArgs', 'K8sSlbAttachmentSlbConfigArgsDict']]]]] = None,
                 __props__=None):
        """
        Binds SLBs to an EDAS k8s application.

        For information about EDAS k8s slb attachment and how to use it, see [What is k8s slb attachment](https://www.alibabacloud.com/help/en/enterprise-distributed-application-service/latest/bindk8sslb).

        > **NOTE:** Available since v1.194.0.

        ## Import

        Slb information of EDAS k8s application can be imported using the ID of an EDAS k8s application. e.g.

        ```sh
        $ pulumi import alicloud:edas/k8sSlbAttachment:K8sSlbAttachment example <EDAS k8s app id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The ID of the EDAS k8s application to which you want to bind SLB instances.
        :param pulumi.Input[Sequence[pulumi.Input[Union['K8sSlbAttachmentSlbConfigArgs', 'K8sSlbAttachmentSlbConfigArgsDict']]]] slb_configs: The configurations of SLB attachment, which is supported for multiple configurations. See `slb_configs` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: K8sSlbAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Binds SLBs to an EDAS k8s application.

        For information about EDAS k8s slb attachment and how to use it, see [What is k8s slb attachment](https://www.alibabacloud.com/help/en/enterprise-distributed-application-service/latest/bindk8sslb).

        > **NOTE:** Available since v1.194.0.

        ## Import

        Slb information of EDAS k8s application can be imported using the ID of an EDAS k8s application. e.g.

        ```sh
        $ pulumi import alicloud:edas/k8sSlbAttachment:K8sSlbAttachment example <EDAS k8s app id>
        ```

        :param str resource_name: The name of the resource.
        :param K8sSlbAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(K8sSlbAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[str]] = None,
                 slb_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['K8sSlbAttachmentSlbConfigArgs', 'K8sSlbAttachmentSlbConfigArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = K8sSlbAttachmentArgs.__new__(K8sSlbAttachmentArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["slb_configs"] = slb_configs
        super(K8sSlbAttachment, __self__).__init__(
            'alicloud:edas/k8sSlbAttachment:K8sSlbAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[str]] = None,
            slb_configs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['K8sSlbAttachmentSlbConfigArgs', 'K8sSlbAttachmentSlbConfigArgsDict']]]]] = None) -> 'K8sSlbAttachment':
        """
        Get an existing K8sSlbAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_id: The ID of the EDAS k8s application to which you want to bind SLB instances.
        :param pulumi.Input[Sequence[pulumi.Input[Union['K8sSlbAttachmentSlbConfigArgs', 'K8sSlbAttachmentSlbConfigArgsDict']]]] slb_configs: The configurations of SLB attachment, which is supported for multiple configurations. See `slb_configs` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _K8sSlbAttachmentState.__new__(_K8sSlbAttachmentState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["slb_configs"] = slb_configs
        return K8sSlbAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[str]:
        """
        The ID of the EDAS k8s application to which you want to bind SLB instances.
        """
        return pulumi.get(self, "app_id")

    @property
    @pulumi.getter(name="slbConfigs")
    def slb_configs(self) -> pulumi.Output[Sequence['outputs.K8sSlbAttachmentSlbConfig']]:
        """
        The configurations of SLB attachment, which is supported for multiple configurations. See `slb_configs` below.
        """
        return pulumi.get(self, "slb_configs")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGatewaysResult',
    'AwaitableGetGatewaysResult',
    'get_gateways',
    'get_gateways_output',
]

@pulumi.output_type
class GetGatewaysResult:
    """
    A collection of values returned by getGateways.
    """
    def __init__(__self__, business_status=None, enable_ipsec=None, gateways=None, id=None, ids=None, include_reservation_data=None, name_regex=None, names=None, output_file=None, status=None, vpc_id=None):
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if enable_ipsec and not isinstance(enable_ipsec, bool):
            raise TypeError("Expected argument 'enable_ipsec' to be a bool")
        pulumi.set(__self__, "enable_ipsec", enable_ipsec)
        if gateways and not isinstance(gateways, list):
            raise TypeError("Expected argument 'gateways' to be a list")
        pulumi.set(__self__, "gateways", gateways)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if include_reservation_data and not isinstance(include_reservation_data, bool):
            raise TypeError("Expected argument 'include_reservation_data' to be a bool")
        pulumi.set(__self__, "include_reservation_data", include_reservation_data)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[str]:
        """
        The business status of the VPN gateway.
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="enableIpsec")
    @_utilities.deprecated("""Field 'enable_ipsec' has been deprecated from provider version 1.193.0 and it will be removed in the future version.""")
    def enable_ipsec(self) -> Optional[bool]:
        """
        Whether the ipsec function is enabled.
        """
        return pulumi.get(self, "enable_ipsec")

    @property
    @pulumi.getter
    def gateways(self) -> Sequence['outputs.GetGatewaysGatewayResult']:
        """
        A list of VPN gateways. Each element contains the following attributes:
        """
        return pulumi.get(self, "gateways")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        IDs of the VPN.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="includeReservationData")
    def include_reservation_data(self) -> Optional[bool]:
        return pulumi.get(self, "include_reservation_data")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        names of the VPN.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the VPN
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[str]:
        """
        ID of the VPC that the VPN belongs.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetGatewaysResult(GetGatewaysResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewaysResult(
            business_status=self.business_status,
            enable_ipsec=self.enable_ipsec,
            gateways=self.gateways,
            id=self.id,
            ids=self.ids,
            include_reservation_data=self.include_reservation_data,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            status=self.status,
            vpc_id=self.vpc_id)


def get_gateways(business_status: Optional[str] = None,
                 enable_ipsec: Optional[bool] = None,
                 ids: Optional[Sequence[str]] = None,
                 include_reservation_data: Optional[bool] = None,
                 name_regex: Optional[str] = None,
                 output_file: Optional[str] = None,
                 status: Optional[str] = None,
                 vpc_id: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewaysResult:
    """
    The VPNs data source lists a number of VPNs resource information owned by an Alicloud account.

    > **NOTE:** Available since v1.18.0.


    :param str business_status: Limit search to specific business status - valid value is "Normal", "FinancialLocked".
    :param bool enable_ipsec: Indicates whether the IPsec-VPN feature is enabled.
    :param Sequence[str] ids: IDs of the VPN.
    :param bool include_reservation_data: Include ineffective ordering data.
    :param str name_regex: A regex string of VPN name.
    :param str output_file: Save the result to the file.
    :param str status: Limit search to specific status - valid value is "Init", "Provisioning", "Active", "Updating", "Deleting".
    :param str vpc_id: Use the VPC ID as the search key.
    """
    __args__ = dict()
    __args__['businessStatus'] = business_status
    __args__['enableIpsec'] = enable_ipsec
    __args__['ids'] = ids
    __args__['includeReservationData'] = include_reservation_data
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpn/getGateways:getGateways', __args__, opts=opts, typ=GetGatewaysResult).value

    return AwaitableGetGatewaysResult(
        business_status=pulumi.get(__ret__, 'business_status'),
        enable_ipsec=pulumi.get(__ret__, 'enable_ipsec'),
        gateways=pulumi.get(__ret__, 'gateways'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        include_reservation_data=pulumi.get(__ret__, 'include_reservation_data'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_gateways_output(business_status: Optional[pulumi.Input[Optional[str]]] = None,
                        enable_ipsec: Optional[pulumi.Input[Optional[bool]]] = None,
                        ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                        include_reservation_data: Optional[pulumi.Input[Optional[bool]]] = None,
                        name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                        output_file: Optional[pulumi.Input[Optional[str]]] = None,
                        status: Optional[pulumi.Input[Optional[str]]] = None,
                        vpc_id: Optional[pulumi.Input[Optional[str]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGatewaysResult]:
    """
    The VPNs data source lists a number of VPNs resource information owned by an Alicloud account.

    > **NOTE:** Available since v1.18.0.


    :param str business_status: Limit search to specific business status - valid value is "Normal", "FinancialLocked".
    :param bool enable_ipsec: Indicates whether the IPsec-VPN feature is enabled.
    :param Sequence[str] ids: IDs of the VPN.
    :param bool include_reservation_data: Include ineffective ordering data.
    :param str name_regex: A regex string of VPN name.
    :param str output_file: Save the result to the file.
    :param str status: Limit search to specific status - valid value is "Init", "Provisioning", "Active", "Updating", "Deleting".
    :param str vpc_id: Use the VPC ID as the search key.
    """
    __args__ = dict()
    __args__['businessStatus'] = business_status
    __args__['enableIpsec'] = enable_ipsec
    __args__['ids'] = ids
    __args__['includeReservationData'] = include_reservation_data
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['status'] = status
    __args__['vpcId'] = vpc_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpn/getGateways:getGateways', __args__, opts=opts, typ=GetGatewaysResult)
    return __ret__.apply(lambda __response__: GetGatewaysResult(
        business_status=pulumi.get(__response__, 'business_status'),
        enable_ipsec=pulumi.get(__response__, 'enable_ipsec'),
        gateways=pulumi.get(__response__, 'gateways'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        include_reservation_data=pulumi.get(__response__, 'include_reservation_data'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEndpointsResult',
    'AwaitableGetEndpointsResult',
    'get_endpoints',
    'get_endpoints_output',
]

@pulumi.output_type
class GetEndpointsResult:
    """
    A collection of values returned by getEndpoints.
    """
    def __init__(__self__, db_cluster_id=None, db_endpoint_id=None, endpoints=None, id=None):
        if db_cluster_id and not isinstance(db_cluster_id, str):
            raise TypeError("Expected argument 'db_cluster_id' to be a str")
        pulumi.set(__self__, "db_cluster_id", db_cluster_id)
        if db_endpoint_id and not isinstance(db_endpoint_id, str):
            raise TypeError("Expected argument 'db_endpoint_id' to be a str")
        pulumi.set(__self__, "db_endpoint_id", db_endpoint_id)
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="dbClusterId")
    def db_cluster_id(self) -> str:
        return pulumi.get(self, "db_cluster_id")

    @property
    @pulumi.getter(name="dbEndpointId")
    def db_endpoint_id(self) -> Optional[str]:
        """
        The endpoint ID.
        """
        return pulumi.get(self, "db_endpoint_id")

    @property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetEndpointsEndpointResult']:
        """
        A list of PolarDB cluster endpoints. Each element contains the following attributes:
        """
        return pulumi.get(self, "endpoints")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetEndpointsResult(GetEndpointsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointsResult(
            db_cluster_id=self.db_cluster_id,
            db_endpoint_id=self.db_endpoint_id,
            endpoints=self.endpoints,
            id=self.id)


def get_endpoints(db_cluster_id: Optional[str] = None,
                  db_endpoint_id: Optional[str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointsResult:
    """
    The `polardb_get_endpoints` data source provides a collection of PolarDB endpoints available in Alibaba Cloud account.
    Filters support regular expression for the cluster name, searches by clusterId, and other filters which are listed below.

    > **NOTE:** Available since v1.68.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    this = alicloud.polardb.get_node_classes(db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        category="Normal")
    default_network = alicloud.vpc.Network("default",
        vpc_name="terraform-example",
        cidr_block="172.16.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=this.classes[0].zone_id,
        vswitch_name="terraform-example")
    cluster = alicloud.polardb.Cluster("cluster",
        db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        db_node_count=2,
        db_node_class=this.classes[0].supported_engines[0].available_resources[0].db_node_class,
        vswitch_id=default_switch.id)
    polardb_clusters_ds = alicloud.polardb.get_clusters_output(description_regex=cluster.description,
        status="Running")
    default = polardb_clusters_ds.apply(lambda polardb_clusters_ds: alicloud.polardb.get_endpoints_output(db_cluster_id=polardb_clusters_ds.clusters[0].id))
    pulumi.export("endpoint", default.endpoints[0].db_endpoint_id)
    ```


    :param str db_cluster_id: PolarDB cluster ID.
    :param str db_endpoint_id: endpoint of the cluster.
    """
    __args__ = dict()
    __args__['dbClusterId'] = db_cluster_id
    __args__['dbEndpointId'] = db_endpoint_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:polardb/getEndpoints:getEndpoints', __args__, opts=opts, typ=GetEndpointsResult).value

    return AwaitableGetEndpointsResult(
        db_cluster_id=pulumi.get(__ret__, 'db_cluster_id'),
        db_endpoint_id=pulumi.get(__ret__, 'db_endpoint_id'),
        endpoints=pulumi.get(__ret__, 'endpoints'),
        id=pulumi.get(__ret__, 'id'))
def get_endpoints_output(db_cluster_id: Optional[pulumi.Input[str]] = None,
                         db_endpoint_id: Optional[pulumi.Input[Optional[str]]] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEndpointsResult]:
    """
    The `polardb_get_endpoints` data source provides a collection of PolarDB endpoints available in Alibaba Cloud account.
    Filters support regular expression for the cluster name, searches by clusterId, and other filters which are listed below.

    > **NOTE:** Available since v1.68.0+.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    this = alicloud.polardb.get_node_classes(db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        category="Normal")
    default_network = alicloud.vpc.Network("default",
        vpc_name="terraform-example",
        cidr_block="172.16.0.0/16")
    default_switch = alicloud.vpc.Switch("default",
        vpc_id=default_network.id,
        cidr_block="172.16.0.0/24",
        zone_id=this.classes[0].zone_id,
        vswitch_name="terraform-example")
    cluster = alicloud.polardb.Cluster("cluster",
        db_type="MySQL",
        db_version="8.0",
        pay_type="PostPaid",
        db_node_count=2,
        db_node_class=this.classes[0].supported_engines[0].available_resources[0].db_node_class,
        vswitch_id=default_switch.id)
    polardb_clusters_ds = alicloud.polardb.get_clusters_output(description_regex=cluster.description,
        status="Running")
    default = polardb_clusters_ds.apply(lambda polardb_clusters_ds: alicloud.polardb.get_endpoints_output(db_cluster_id=polardb_clusters_ds.clusters[0].id))
    pulumi.export("endpoint", default.endpoints[0].db_endpoint_id)
    ```


    :param str db_cluster_id: PolarDB cluster ID.
    :param str db_endpoint_id: endpoint of the cluster.
    """
    __args__ = dict()
    __args__['dbClusterId'] = db_cluster_id
    __args__['dbEndpointId'] = db_endpoint_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:polardb/getEndpoints:getEndpoints', __args__, opts=opts, typ=GetEndpointsResult)
    return __ret__.apply(lambda __response__: GetEndpointsResult(
        db_cluster_id=pulumi.get(__response__, 'db_cluster_id'),
        db_endpoint_id=pulumi.get(__response__, 'db_endpoint_id'),
        endpoints=pulumi.get(__response__, 'endpoints'),
        id=pulumi.get(__response__, 'id')))
